from distutils.core import setup
setup(
  name = 'sus2',
  packages = ['sus2'],
  version = '0.1',
  license='MIT',
  description = 'Useful module for operating sus objects',
  author = 'yharonsoup',
  author_email = 'yharonsoup@gmail.com',
  url = 'https://github.com/yharonsoup/sus2/',
  download_url = 'https://github.com/yharonsoup/sus2/archive/refs/tags/v_01.tar.gz',
  keywords = ['sus', 'amogus'],
  install_requires=[],
  classifiers=[
    'Development Status :: 3 - Alpha',
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
  ],
)
